@@ -11,14 +11,17 @@ circlin.cor <- function(theta, x, rads = FALSE) {
   ## x is euclidean variable or a matrix containing euclidean variables
   x <- as.matrix(x)
   n <- length(theta)  ## sample size
-  if (rads == FALSE)  theta <- theta * pi/180
-  rxc <- as.numeric( cor(cos(theta), x) )  ## and cos(theta) and x correlation
-  rxs <- as.numeric( cor(sin(theta), x) )  ## sin(theta) and x correlation
-  rcs <- cor(cos(theta), sin(theta))  ## cos(theta) and sin(theta) correlation
+  if (rads == F)  theta <- theta * pi/180
+  costheta <- cos(theta)
+  sintheta <- sin(theta)
+
+  rxc <- as.numeric( cor(costheta, x) )  ## and cos(theta) and x correlation
+  rxs <- as.numeric( cor(sintheta, x) )  ## sin(theta) and x correlation
+  rcs <- cor(costheta, sintheta)  ## cos(theta) and sin(theta) correlation
   R2xt <- (rxc^2 + rxs^2 - 2 * rxc * rxs * rcs)/(1 - rcs^2)
   ## linear-circular correlation
   Ft <- (n - 3) * R2xt/(1 - R2xt)  ## F-test statistic value
-  pvalue <- 1 - pf(Ft, 2, n - 3)
+  pvalue <- pf(Ft, 2, n - 3, lower.tail = FALSE)
   res <- cbind(R2xt, pvalue)
   colnames(res) <- c('R-squared', 'p-value')
   res
