@@ -14,6 +14,7 @@ rvmf <- function(n, mu, k) {
   ## k is the concentration parameter
   ## n is the sample size
   d <- length(mu)  ## the dimensions
+  
   if (k > 0) {
   mu <- mu/sqrt(sum(mu^2))  ## the mean direction
   ini <- c(numeric(d - 1), 1)  ## mean direction is set to (0, ..., 0, 1)
@@ -23,25 +24,26 @@ rvmf <- function(n, mu, k) {
   m <- 0.5 * (d - 1)
   c <- k * x0 + (d - 1) * log(1 - x0^2)
   for (i in 1:n) {
-    t <- -1000
+    ta <-  -1000
     u <- 1
-    while (t - c < log(u)) {
+    while (ta - c < log(u)) {
       z <- rbeta(1, m, m)
       u <- runif(1)
-      w <- (1 - (1 + b) * z)/(1 - (1 - b) * z)
-      t <- k * w + (d - 1) * log(1 - x0 * w)
+      w <- (1 - (1 + b) * z)/( 1 - (1 - b) * z )
+      ta <- k * w + (d - 1) * log(1 - x0 * w)
     }
     v1 <- rnorm(d - 1)   
-    v <- v1 / sqrt( sum(v1^2) )
+    v <- v1/sqrt(sum(v1^2))
     S[i, ] <- c(sqrt(1 - w^2) * v, w)
   }
   A <- rotation(ini, mu)  ## calculate the rotation matrix
   ## in order to rotate the initial mean direction from ini to mu
   x <- tcrossprod(S, A)  ## the x has direction mu 
+  
   } else {  ## uniform distribution
   ## requires MASS if k = 0
-  x1 <- MASS::mvrnorm( n, numeric(d), diag(d) )
+  x1 <- MASS::mvrnorm(n, numeric(d), diag(d))
   x <- x1 / sqrt( rowSums(x1^2) )
   } 
   x
-}
\ No newline at end of file
+} 
